@@ -26,17 +26,17 @@
 class TextBannerItem : public QGraphicsTextItem, public ReloadableItem
 {
 public:
-    explicit TextBannerItem(QGraphicsItem *parent = 0);
+    explicit TextBannerItem(QGraphicsItem *parent = nullptr);
 
-    void reload(const QSize &size) Q_DECL_OVERRIDE;
+    void reload(const QSize &size) override;
 };
 
 class PauseBannerItem : public TextBannerItem
 {
 public:
-    explicit PauseBannerItem(QGraphicsItem *parent = 0);
+    explicit PauseBannerItem(QGraphicsItem *parent = nullptr);
 
-    void reload(const QSize &size) Q_DECL_OVERRIDE;
+    void reload(const QSize &size) override;
 };
 
 #endif // TEXTBANNERITEM_H
